.. image:: https://user-images.githubusercontent.com/16875803/66711530-9bdbab80-ed42-11e9-913f-7a21ede86d8f.png
   :target: https://user-images.githubusercontent.com/16875803/66711530-9bdbab80-ed42-11e9-913f-7a21ede86d8f.png
   :alt: pattoo

pattoo-shared
=============
   
Shared libraries for Pattoo Servers and Agents
